import os.path
from typing import Optional

from ._git import Git as _Git
from ._mercurial import Mercurial as _Mercurial
from ._repo import Repo, repo_kind


class UnknownRepositoryTypeException(Exception):
    """Exception indicating the repository type is unknown"""


def get_repo(directory, kind: Optional[repo_kind] = None) -> Repo:
    """Return a Repo for a local directory"""
    if kind is None:
        if os.path.exists(os.path.join(directory, ".hg")):
            return _Mercurial(directory)
        # use git.repo.fun.is_git_dir ?
        if os.path.exists(os.path.join(directory, ".git")):
            return _Git(directory)
    else:
        # TODO use enum instead of str
        if kind in ("hg", "mercurial"):
            return _Mercurial(directory)
        if kind == "git":
            return _Git(directory)
    raise UnknownRepositoryTypeException()


def clone_from(kind: repo_kind, url: str, to_path) -> Repo:
    """Clone a repository of version system *kind*, URL *url into *to_path*.

    :return: cloned repository
    """
    if kind in ("hg", "mercurial"):
        return _Mercurial.clone_from(url, to_path)
    if kind == "git":
        return _Git.clone_from(url, to_path)
    raise UnknownRepositoryTypeException()
