import os
from logging import Logger
from threading import Thread


# Mostly copied from https://stackoverflow.com/a/61111999
class LogPipe(Thread):
    def __init__(self, logger: Logger, level: int):
        """Set up the object with a logger and a loglevel
        and start the thread
        """
        super().__init__()
        self.daemon = False
        self.logger = logger
        self.level = level
        self.fd_read, self.fd_write = os.pipe()
        self.pipe_reader = os.fdopen(self.fd_read)
        self.start()

    def fileno(self):
        """Return the write file descriptor of the pipe"""
        return self.fd_write

    def run(self):
        """Run the thread, logging everything."""
        for line in iter(self.pipe_reader.readline, ""):
            self.logger.log(self.level, line.strip("\n"))

        self.pipe_reader.close()

    def close(self):
        """Close the write end of the pipe."""
        os.close(self.fd_write)
