"""Function to help find a program path"""

import os
from typing import Optional


def which(program: str) -> Optional[str]:
    """Return path of program if it exists
    from:
    https://stackoverflow.com/questions/377017/test-if-executable-exists-in-python/377028#377028
    """

    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    fpath, _fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file

    return None
