"""Command line interface for options"""

import argparse
import sys
from typing import List, Optional

from ._config import Configuration
from ._parsing import apply, basic_parser

__version__ = "1.0.0"
__date__ = "2024-10-24"
__updated__ = "2024-10-24"


def __parser():
    program_version_message = "%(prog)s"
    program_shortdesc = __doc__.split(".", maxsplit=1)[0]
    program_license = f"""{program_shortdesc}

      Created by Vincent Hatakeyama on {__date__}.
      Copyright 2024 XCG Consulting. All rights reserved.

      Licensed under the MIT License

      Distributed on an "AS IS" basis without warranties
      or conditions of any kind, either express or implied.

    USAGE
    """
    parser = basic_parser(program_license, program_version_message, False)
    _add_parser_options(parser)
    return parser


def _add_parser_options(parser: argparse.ArgumentParser):
    parser.add_argument(
        "--key",
        help="Key to display",
        default=None,
    )


class _Options:
    def __init__(
        self,
        key: Optional[str],
    ):
        self.source_directory = "."
        self.key = key


def _get_options(namespace: argparse.Namespace) -> _Options:
    return _Options(
        namespace.key,
    )


def main(argv: Optional[List[str]] = None) -> int:
    """Copy modules for a build, callable version that parses arguments"""
    parser = __parser()
    nmspc = parser.parse_args(argv)
    apply(nmspc)
    options = _get_options(nmspc)
    _print_configuration(options)
    return 0


def _print_configuration(options: _Options):
    """Display configuration. Useful for development of odoo_scripts."""
    c = Configuration(options.source_directory)
    if options.key:
        value = getattr(c, options.key)

        if value is None:
            print()
        else:
            print(value)
    else:
        for key, value in c.__dict__.items():
            print(key, "=", value)


if __name__ == "__main__":
    sys.exit(main())
