"""Py3o methods"""

import atexit
import logging
from functools import partial

from python_on_whales import docker

from ._docker_client import CaptureDockerExitCode, find_container, stop_remove

_logger = logging.getLogger(__name__)


def start_py3o(host_fusion_port: int = 8765, stop_at_exit: bool = True):
    """start a py3o container"""
    fusion_repository = "xcgd/py3o"
    fusion_version = "1.0.0"
    fusion_name = "py3o_fusion"
    fusion_image = f"{fusion_repository}:{fusion_version}"
    with CaptureDockerExitCode() as exit_code:
        _logger.debug("Pulling %s", fusion_repository)
        docker.image.pull(f"{fusion_repository}:{fusion_version}")
    if exit_code:
        _logger.warning("Error when pulling")
    container = find_container(fusion_name)
    if container is not None:
        _logger.debug("%s Container already running", fusion_name)
        stop_remove(container)
    # TODO handle --host-network option
    port_bindings = [(8765, host_fusion_port)]
    _logger.debug("Starting %s container", fusion_name)
    fusion = docker.container.create(
        image=fusion_image, publish=port_bindings, name=fusion_name
    )
    _logger.debug("Starting %s container", fusion_name)
    fusion.start()

    stop_py3o = partial(stop_remove, fusion, volumes=True)
    if stop_at_exit:
        atexit.register(stop_py3o)
    return fusion_name, stop_py3o
